@@ -26,16 +26,30 @@
 #' @export
 #' @examples
 #' \dontrun{
+#' ## ======================
+#' ##    `mgsub` Function
+#' ## ======================
+#' 
 #' multigsub(c("it's", "I'm"), c("it is", "I am"), DATA$state)
 #' mgsub(c("it's", "I'm"), c("it is", "I am"), DATA$state)
 #' mgsub("[[:punct:]]", "PUNC", DATA$state, fixed = FALSE)
-#' 
+#'
+#' ## ====================== 
 #' ## `sub_holder` Function
+#' ## ======================
+#' 
+#' ## `alpha.type` as TRUE
 #' (fake_dat <- paste(emoticon[1:11,2], DATA$state))
 #' (m <- sub_holder(emoticon[,2], fake_dat))
 #' m$unhold(strip(m$output))
 #' # With Stemming
 #' m$unhold(stemmer(strip(m$output), capitalize = FALSE))
+#' 
+#' ## `alpha.type` as FALSE (numeric keys)
+#' vowels <- LETTERS[c(1, 5, 9, 15, 21)]
+#' (m2 <- sub_holder(vowels, toupper(DATA$state), alpha.type = FALSE))
+#' m2$unhold(gsub("[^0-9]", "", m2$output))
+#' mtabulate(strsplit(m2$unhold(gsub("[^0-9]", "", m2$output)), ""))
 #' }
 multigsub <-
 function(pattern, replacement = NULL, text.var, leadspace = FALSE, 
@@ -87,6 +101,8 @@ mgsub <- multigsub
 #' values, allowing the user to manipulate the vector and then revert the place
 #' holders back to the original values.
 #' 
+#' @param alpha.type logical.  If \code{TRUE} alpha (lower case letters) are 
+#' used for the key.  If \code{FALSE} numbers are used as the key.
 #' @return \code{sub_holder} - Returns a list with the following:
 #' \item{output}{keyed place holder character vector} 
 #' \item{unhold}{A function used to revert back to the original values}
@@ -96,19 +112,23 @@ mgsub <- multigsub
 #' pattern of `qdapplaceholder` followed by lower case letter keys followed by
 #' `qdap`.
 #' @export
-sub_holder <- function(pattern, text.var, ...) {
+sub_holder <- function(pattern, text.var, alpha.type = TRUE, ...) {
 
     if (!is.character(pattern)) pattern <- as.character(pattern)
     x2 <- x <- length(pattern)
-    counter <- 0
-    while(x > 26) {
-        x <- x/26
-        counter <- counter + 1
-    }
-    if (x > 0) counter + 1
 
-    keys <- paste2(expand.grid(lapply(1:counter, function(i) letters)), sep="")
-    reps <- paste0("qdapplaceholder", keys, "qdap")
+    if (alpha.type) {
+        counter <- 0
+        while(x > 26) {
+            x <- x/26
+            counter <- counter + 1
+        }
+        if (x > 0) counter + 1
+        keys <- paste2(expand.grid(lapply(1:counter, function(i) letters)), sep="")
+        reps <- paste0("qdapplaceholder", keys, "qdap")
+    } else {
+        keys <- reps <- 1:x
+    }
 
     output <- mgsub(pattern, reps, text.var, ...)
 
