@@ -61,7 +61,7 @@
 #' This function defaults to the word polarity dictionary used by Hu, M., & 
 #' Liu, B. (2004), however, this may not be appropriate for the context of 
 #' children in a classroom.  The user may (is encouraged) to provide/augment the 
-#' dictionary (see the \code{polarity_frame} function).  For instance the word 
+#' dictionary (see the \code{sentiment_frame} function).  For instance the word 
 #' "sick" in a high school setting may mean that something is good, whereas 
 #' "sick" used by a typical adult indicates something is not right or negative 
 #' connotation (\strong{deixis}).
@@ -367,7 +367,7 @@ polarity <- function (text.var, grouping.var = NULL,
     ## replace commas for later consideration
     DF[, "text.var"] <- gsub(",", " longreplacementbreakoff ", DF[, "text.var"])
 
-    ## An hash key to look up polarized words
+    ## A hash key to look up polarized words
     if (!is.hash(polarity.frame)) {
         if (!is.data.frame(polarity.frame)) {
             stop(paste("Please supply a dataframe or hash_key", 
@@ -595,50 +595,6 @@ print.polarity_count <-
 
 
 
-#' Polarity Score (Sentiment Analysis)
-#' 
-#' \code{polarity_frame} - Generate a polarity lookup hash key 
-#' for use with the \code{polarity.frame} argument in the \code{polarity} 
-#' function.
-#' 
-#' @param positives A character vector of positive words.
-#' @param negatives A character vector of negative words.
-#' @param pos.weights A vector of weights to weight each positive word by.  
-#' Length must be equal to length of \code{postives} or length 1 (if 1 weight 
-#' will be recycled). 
-#' @param neg.weights A vector of weights to weight each negative word by.  
-#' Length must be equal to length of \code{negatives} or length 1 (if 1 weight 
-#' will be recycled). 
-#' @export
-#' @rdname polarity
-polarity_frame <- function(positives, negatives, pos.weights = 1, 
-    neg.weights = -1) {
-    
-    .Deprecated(msg = paste("polarity_frame is deprecated.  Please use the", 
-        "sentiment_frame function instead."), 
-        old = as.character(sys.call(sys.parent()))[1L])    
-    
-    plen <- length(positives)
-    nlen <- length(negatives)
-    if (!length(plen) %in% c(length(positives), 1)) {
-        stop("The length of positives and pos.weights must be equal")
-    }
-    if (!length(nlen) %in% c(length(negatives), 1)) {
-        stop("The length of negatives and negative weights must be equal")
-    }
-    if (length(pos.weights) == 1) {
-        pos.weights <- rep(pos.weights, plen)
-    }
-    if (length(neg.weights) == 1) {
-        neg.weights <- rep(neg.weights, nlen)
-    }
-    dat <- data.frame(words = c(positives, negatives), polarity = c(pos.weights, 
-        neg.weights), stringsAsFactors = FALSE)
-    hash(dat)
-}
-
-
-
 #' Plots a polarity Object
 #' 
 #' Plots a polarity object as a heat map Gantt plot with polarity over 
@@ -1582,4 +1538,3 @@ colorize <- function(x, y) {
 
 
 
-
