@@ -42,9 +42,10 @@
 #' \code{\link[qdap]{TOT}} 
 #' @keywords sentence, split, turn-of-talk
 #' @export
+#' @importFrom dplyr tbl_df
 #' @examples
 #' \dontrun{
-#' ## `sentSpli`t EXAMPLE:
+#' ## `sentSplit` EXAMPLE:
 #' (out <- sentSplit(DATA, "state"))
 #' sentSplit(DATA, "state", stem.col = TRUE)
 #' sentSplit(DATA, "state", text.place = "left")
@@ -113,6 +114,7 @@ function(dataframe, text.var, rm.var = NULL, endmarks = c("?", ".", "!", "|"),
     if (!is.null(rm.var)) {
         rm.var <- paste0("rmvars_", paste(rm.var, collapse = ":"))
     } 
+    output <- tbl_df(output)
     class(output) <- c("sent_split", paste0("sent_split_text_var:", text.var), 
         rm.var, class(output))
     attributes(output)[["text.var"]] <- text.var
@@ -279,7 +281,7 @@ function(tot){
 #' 
 #' @param x The sent_split object
 #' @param \ldots ignored
-#' @S3method print sent_split
+#' @export
 #' @method print sent_split
 print.sent_split <-
 function(x, ...) {
